Documentation
¶
Index ¶
- func MDToHTML(content string) (string, bool)
- type NextBehavior
- type SystemMsgs
- type Theme
- func (theme Theme) DateSeperator(date time.Time) string
- func (theme Theme) HTMLHead(title string) string
- func (theme *Theme) LoadTheme(themeName string, DW_MEDIA bool)
- func (theme Theme) MessageComponent(msg discord.Message, previousMsg discord.Message, firstMsg bool) string
- func (theme Theme) StartChannel(channel discord.Channel) string
- func (theme Theme) StartDM(author discord.Author) string
- func (theme Theme) StartGroupDM(groupDM discord.Channel) string
- func (theme Theme) TopBar(title string, channelType discord.ChannelType) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type NextBehavior ¶
type NextBehavior int8
const ( // The things must put on the out most characters of the group NB_Spread NextBehavior = iota // Stop at the first match, ie. // // ~~~asdasdad~~~ // // ^^_________^^_ NB_Stop // Ignores the match if there is another one of it's symbols after it. ie. // // _aa_: ok // // __aa_: ok // // _^__^ // // _aa__: not ok NB_Ignore )
type SystemMsgs ¶
type SystemMsgs struct {
USR_ADD,
USR_RM,
CALL,
RENAME,
ICON_CH,
PIN,
MEM_JOIN string
}
type Theme ¶
type Theme struct {
BaseCss,
ThemeDir,
MSG_WITH_PFP,
MSG,
MSG_INP_BAR,
SVG_DM,
SVG_CHANNEL,
SVG_GROUP_DM,
DATE_SEPERATOR,
DM_START,
HTML_HEAD,
TOP_BAR,
START_CHAN,
REPLY,
STICKER,
GIF,
OTHER_MIME,
MENTION,
CUSTOM_EMOJI,
EMOJI_WRAPPER,
REACTION,
REACTION_WRAPPER,
IMG string
DownloadMedia bool
}
func (Theme) MessageComponent ¶
Click to show internal directories.
Click to hide internal directories.